@@ -25,8 +25,8 @@
  transform is placed on the font to shrink it back to the desired
  size.  While it is a bit surprising that the dpi setting affects
  hinting, whereas the global transform does not, this is documented
- behavior of freetype, and therefore hopefully unlikely to change.
- The freetype 2 tutorial says:
+ behavior of FreeType, and therefore hopefully unlikely to change.
+ The FreeType 2 tutorial says:
 
       NOTE: The transformation is applied to every glyph that is
       loaded through FT_Load_Glyph and is completely independent of
@@ -280,9 +280,8 @@ int FT2Font::get_path_count()
             }
         }
 
-        count++;
-
     Count_Close:
+        count++;
         first = last + 1;
     }
 
@@ -478,11 +477,10 @@ void FT2Font::get_path(double *outpoints, unsigned char *outcodes)
             }
         }
 
+    Close:
         (*outpoints++) = 0.0;
         (*outpoints++) = 0.0;
         (*outcodes++) = ENDPOLY;
-
-    Close:
         first = last + 1;
     }
 }
@@ -511,6 +509,10 @@ FT2Font::FT2Font(FT_Open_Args &open_args, long hinting_factor_) : image(), face(
         throw "Could not set the fontsize";
     }
 
+    if (open_args.stream != NULL) {
+        face->face_flags |= FT_FACE_FLAG_EXTERNAL_STREAM;
+    }
+
     static FT_Matrix transform = { 65536 / hinting_factor, 0, 0, 65536 };
     FT_Set_Transform(face, &transform, 0);
 }
@@ -570,7 +572,7 @@ void FT2Font::select_charmap(unsigned long i)
     }
 }
 
-int FT2Font::get_kerning(int left, int right, int mode)
+int FT2Font::get_kerning(FT_UInt left, FT_UInt right, FT_UInt mode)
 {
     if (!FT_HAS_KERNING(face)) {
         return 0;
@@ -585,7 +587,7 @@ int FT2Font::get_kerning(int left, int right, int mode)
 }
 
 void FT2Font::set_text(
-    size_t N, uint32_t *codepoints, double angle, FT_UInt32 flags, std::vector<double> &xys)
+    size_t N, uint32_t *codepoints, double angle, FT_Int32 flags, std::vector<double> &xys)
 {
     angle = angle / 360.0 * 2 * M_PI;
 
@@ -662,7 +664,7 @@ void FT2Font::set_text(
     }
 }
 
-void FT2Font::load_char(long charcode, FT_UInt32 flags)
+void FT2Font::load_char(long charcode, FT_Int32 flags)
 {
     int error = FT_Load_Char(face, (unsigned long)charcode, flags);
 
@@ -680,7 +682,7 @@ void FT2Font::load_char(long charcode, FT_UInt32 flags)
     glyphs.push_back(thisGlyph);
 }
 
-void FT2Font::load_glyph(FT_UInt glyph_index, FT_UInt32 flags)
+void FT2Font::load_glyph(FT_UInt glyph_index, FT_Int32 flags)
 {
     int error = FT_Load_Glyph(face, glyph_index, flags);
 
